==> tencentcloud-sdk-java-3.1.72-sources.jar: com/tencentcloudapi/clb/v20180317/models/DescribeLoadBalancerListByCertIdRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.clb.v20180317.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeLoadBalancerListByCertIdRequest extends AbstractModel{

    /**
    * 服务端证书的ID，或客户端证书的ID
    */
    @SerializedName("CertIds")
    @Expose
    private String [] CertIds;

    /**
     * Get 服务端证书的ID，或客户端证书的ID 
     * @return CertIds 服务端证书的ID，或客户端证书的ID
     */
    public String [] getCertIds() {
        return this.CertIds;
    }

    /**
     * Set 服务端证书的ID，或客户端证书的ID
     * @param CertIds 服务端证书的ID，或客户端证书的ID
     */
    public void setCertIds(String [] CertIds) {
        this.CertIds = CertIds;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "CertIds.", this.CertIds);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/clb/v20180317/models/DescribeLoadBalancerListByCertIdRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.clb.v20180317.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeLoadBalancerListByCertIdRequest extends AbstractModel{

    /**
    * 服务端证书的ID，或客户端证书的ID
    */
    @SerializedName("CertIds")
    @Expose
    private String [] CertIds;

    /**
     * Get 服务端证书的ID，或客户端证书的ID 
     * @return CertIds 服务端证书的ID，或客户端证书的ID
     */
    public String [] getCertIds() {
        return this.CertIds;
    }

    /**
     * Set 服务端证书的ID，或客户端证书的ID
     * @param CertIds 服务端证书的ID，或客户端证书的ID
     */
    public void setCertIds(String [] CertIds) {
        this.CertIds = CertIds;
    }

    public DescribeLoadBalancerListByCertIdRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeLoadBalancerListByCertIdRequest(DescribeLoadBalancerListByCertIdRequest source) {
        if (source.CertIds != null) {
            this.CertIds = new String[source.CertIds.length];
            for (int i = 0; i < source.CertIds.length; i++) {
                this.CertIds[i] = new String(source.CertIds[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "CertIds.", this.CertIds);

    }
}
